/**
 * The sentinal sample!
 *
 * Copyright 2009 Radu Motisan
 * www.pocketmagic.net
 */

package com.rim.samples.device.helloworld;

//import com.rim.samples.device.resource.*;
import net.rim.device.api.ui.*;
import net.rim.device.api.ui.component.*;
import net.rim.device.api.ui.container.*;
import net.rim.device.api.i18n.*;
import net.rim.device.api.system.*;
import net.rim.device.api.collection.util.*;
//
import java.util.Timer;
import java.util.TimerTask;


/**
 * The HelloWorld sample demonstrates some of the most basic features
 * of the RIM UI and internationalization (i18n).
 */
public class HelloWorld extends UiApplication
{
    //statics ------------------------------------------------------------------
    public static void main(String[] args)
    {
        HelloWorld theApp = new HelloWorld();
        //To make the application enter the event thread and start processing messages, we invoke the enterEventDispatcher method
        theApp.enterEventDispatcher();
    }

    /**
     * the default constructor. Creates all the RIM UI components and pushes the application's root screen onto the UI stack
     */
    public HelloWorld()
    {
        //Push the main screen instance onto the UI stack for rendering.
        pushScreen(new HelloWorldScreen());
    }
    
}

final class HelloWorldScreen extends MainScreen
{
    //members ------------------------------------------------------------------    
    /**
     * Add the title and a simple richtext field
     */
    RichTextField RT1;
    Timer timer;
    Bitmap img;
    
    public HelloWorldScreen()
    {
        super(DEFAULT_MENU | DEFAULT_CLOSE);
        
        //Add a field to the title region of the screen. We use a simple LabelField here. The ELLIPSIS option truncates
        // the label text with "..." if the text was too long for the space available.
        setTitle(new LabelField("AppTitle", 
            LabelField.ELLIPSIS | LabelField.FIELD_HCENTER | LabelField.USE_ALL_WIDTH));
           init();
    }
    
    public void init()
    {
        //Add a read only text field (RichTextField) to the field portion of the screen. The RTF is focusable by default.
        RT1 = new RichTextField("test content");
        add(RT1);
        //timer
        timer = new Timer (  ) ;
        timer.schedule ( new ToDoTask (  ) , 5*1000 ) ; //5sec
        //res
        img = Bitmap.getBitmapResource("helloworld_jde.png");
    }
    class ToDoTask extends TimerTask  
    {
        public void run (  )   
        {
            //System.out.println ( "OK, It's time to do something!" ) ;
            //timer.cancel (  ) ; //Terminate the thread
            RT1.setText(RT1.getText() + "[tim]");
        }
    }

    //WM_PAINT
    public void paint(Graphics g) 
    {
        
        XYRect r = g.getClippingRect();//getBounds();
        int hlines = r.height / 10;
        int vlines = r.width / 10;
        int i, top = 0;
        
       //draw grid
        for (i = 0; i <= hlines; i++) //hori lines
        {
           g.setColor(Color.DARKORANGE);
            g.drawLine(0, top+i * 10, r.width, top+ i * 10);
        }
        for (i = 0; i <= vlines; i++) 
        {
            g.setColor(Color.GREEN);
            g.drawLine(i * 10, 0+top, i * 10, r.height);
        }
        
        g.drawBitmap(0,0,32,32,img,0,0); //draw an image
        
        
        FontFamily fontFamily1 = Font.getDefault().getFontFamily();
        Font font1 = fontFamily1.getFont(Font.BOLD,20);
        g.setFont(font1);
        g.setColor(Color.BLACK);
        g.drawText("Hello World",10,100,Graphics.HCENTER); 
        font1 = fontFamily1.getFont(Font.BOLD,14);
        g.setFont(font1);
        g.setColor(Color.BLUE);
        g.drawText("www.pocketmagic.net",10,150,Graphics.HCENTER); 
    }
 
    //WM_CLOSE
    public boolean onClose()
    {
        if (Dialog.ask(Dialog.D_YES_NO,"Exit app?") == Dialog.YES)
            System.exit(0);
        return true;
    }

    public boolean keyChar(char key, int status, int time) {
        //intercept the ESC key - exit the app on its receipt
        boolean retval = false;

        switch (key) 
        {
            case Characters.ENTER: //adds more text to the richtext control
                RT1.setText(RT1.getText() + " more content ");
                retval = true;
            break;
            case Characters.ESCAPE:
                onClose();
                retval = true;
            break;
        }

        return retval;
    }
}
